@@ -16,6 +16,7 @@ OPTIONS:
    -d      Use Dockerfile-dev for a git clone build
    -b      Branch to use (default = master)
    -r      Destroy and rebuild the buildx environment
+   -v      aprsd version to build
 EOF
 }
 
@@ -25,7 +26,7 @@ DEV=0
 REBUILD_BUILDX=0
 TAG="latest"
 BRANCH=${BRANCH:-master}
-VERSION="3.0.0"
+VERSION="3.3.4"
 
 while getopts “hdart:b:v:” OPTION
 do
@@ -62,8 +63,9 @@ done
 
 if [ $ALL_PLATFORMS -eq 1 ]
 then
-    PLATFORMS="linux/arm/v7,linux/arm64,linux/amd64"
+    PLATFORMS="linux/arm64,linux/amd64"
     #PLATFORMS="linux/arm/v7,linux/arm/v6,linux/amd64"
+    #PLATFORMS="linux/arm64"
 else
     PLATFORMS="linux/amd64"
 fi
@@ -87,8 +89,9 @@ then
     echo "Build -DEV- with tag=${TAG} BRANCH=${BRANCH} platforms?=${PLATFORMS}"
     # Use this script to locally build the docker image
     docker buildx build --push --platform $PLATFORMS \
-        -t harbor.hemna.com/hemna6969/aprsd:$TAG \
-        -f Dockerfile-dev --build-arg branch=$BRANCH \
+        -t hemna6969/aprsd:$TAG \
+        --build-arg INSTALL_TYPE=github \
+        --build-arg branch=$BRANCH \
         --build-arg BUILDX_QEMU_ENV=true \
         --no-cache .
 else
@@ -99,6 +102,5 @@ else
         --build-arg BUILDX_QEMU_ENV=true \
         -t hemna6969/aprsd:$VERSION \
         -t hemna6969/aprsd:$TAG \
-        -t hemna6969/aprsd:latest \
-        -f Dockerfile .
+        -t hemna6969/aprsd:latest .
 fi
