@@ -2,12 +2,16 @@ from unittest import mock
 
 from oslo_config import cfg
 
-from aprsd import client, packets
-from aprsd import conf  # noqa: F401
+from aprsd import (  # noqa: F401
+    client,
+    conf,
+    packets,
+)
+from aprsd.client.drivers.registry import DriverRegistry
 from aprsd.plugins import notify as notify_plugin
 
 from .. import fake, test_plugin
-
+from ..mock_client_driver import MockClientDriver
 
 CONF = cfg.CONF
 DEFAULT_WATCHLIST_CALLSIGNS = fake.FAKE_FROM_CALLSIGN
@@ -15,9 +19,24 @@ DEFAULT_WATCHLIST_CALLSIGNS = fake.FAKE_FROM_CALLSIGN
 
 class TestWatchListPlugin(test_plugin.TestPlugin):
     def setUp(self):
+        super().setUp()
         self.fromcall = fake.FAKE_FROM_CALLSIGN
         self.ack = 1
 
+        # Mock APRSISDriver
+        self.aprsis_patcher = mock.patch('aprsd.client.drivers.aprsis.APRSISDriver')
+        self.mock_aprsis = self.aprsis_patcher.start()
+        self.mock_aprsis.is_enabled.return_value = False
+        self.mock_aprsis.is_configured.return_value = False
+
+        # Register the mock driver
+        DriverRegistry().register(MockClientDriver)
+
+    def tearDown(self):
+        super().tearDown()
+        if hasattr(self, 'aprsis_patcher'):
+            self.aprsis_patcher.stop()
+
     def config_and_init(
         self,
         watchlist_enabled=True,
@@ -28,7 +47,9 @@ class TestWatchListPlugin(test_plugin.TestPlugin):
     ):
         CONF.callsign = self.fromcall
         CONF.aprs_network.login = self.fromcall
-        CONF.aprs_fi.apiKey = "something"
+        CONF.aprs_fi.apiKey = 'something'
+        # Add mock password
+        CONF.aprs_network.password = '12345'
 
         # Set the watchlist specific config options
         CONF.watch_list.enabled = watchlist_enabled
@@ -49,28 +70,25 @@ class TestWatchListPlugin(test_plugin.TestPlugin):
 
 
 class TestAPRSDWatchListPluginBase(TestWatchListPlugin):
-
     def test_watchlist_not_enabled(self):
         self.config_and_init(watchlist_enabled=False)
         plugin = fake.FakeWatchListPlugin()
 
         packet = fake.fake_packet(
-            message="version",
+            message='version',
             msg_number=1,
         )
         actual = plugin.filter(packet)
         expected = packets.NULL_MESSAGE
         self.assertEqual(expected, actual)
 
-    @mock.patch("aprsd.client.ClientFactory", autospec=True)
-    def test_watchlist_not_in_watchlist(self, mock_factory):
-        client.factory = mock_factory
+    def test_watchlist_not_in_watchlist(self):
         self.config_and_init()
         plugin = fake.FakeWatchListPlugin()
 
         packet = fake.fake_packet(
-            fromcall="FAKE",
-            message="version",
+            fromcall='FAKE',
+            message='version',
             msg_number=1,
         )
         actual = plugin.filter(packet)
@@ -79,91 +97,82 @@ class TestAPRSDWatchListPluginBase(TestWatchListPlugin):
 
 
 class TestNotifySeenPlugin(TestWatchListPlugin):
-
     def test_disabled(self):
         self.config_and_init(watchlist_enabled=False)
         plugin = notify_plugin.NotifySeenPlugin()
 
         packet = fake.fake_packet(
-            message="version",
+            message='version',
             msg_number=1,
         )
         actual = plugin.filter(packet)
         expected = packets.NULL_MESSAGE
         self.assertEqual(expected, actual)
 
-    @mock.patch("aprsd.client.ClientFactory", autospec=True)
-    def test_callsign_not_in_watchlist(self, mock_factory):
-        client.factory = mock_factory
+    def test_callsign_not_in_watchlist(self):
         self.config_and_init(watchlist_enabled=False)
         plugin = notify_plugin.NotifySeenPlugin()
 
         packet = fake.fake_packet(
-            message="version",
+            message='version',
             msg_number=1,
         )
         actual = plugin.filter(packet)
         expected = packets.NULL_MESSAGE
         self.assertEqual(expected, actual)
 
-    @mock.patch("aprsd.client.ClientFactory", autospec=True)
-    @mock.patch("aprsd.packets.WatchList.is_old")
-    def test_callsign_in_watchlist_not_old(self, mock_is_old, mock_factory):
-        client.factory = mock_factory
+    @mock.patch('aprsd.packets.WatchList.is_old')
+    def test_callsign_in_watchlist_not_old(self, mock_is_old):
         mock_is_old.return_value = False
         self.config_and_init(
             watchlist_enabled=True,
-            watchlist_callsigns=["WB4BOR"],
+            watchlist_callsigns=['WB4BOR'],
         )
         plugin = notify_plugin.NotifySeenPlugin()
 
         packet = fake.fake_packet(
-            fromcall="WB4BOR",
-            message="ping",
+            fromcall='WB4BOR',
+            message='ping',
             msg_number=1,
         )
         actual = plugin.filter(packet)
         expected = packets.NULL_MESSAGE
         self.assertEqual(expected, actual)
 
-    @mock.patch("aprsd.client.ClientFactory", autospec=True)
-    @mock.patch("aprsd.packets.WatchList.is_old")
-    def test_callsign_in_watchlist_old_same_alert_callsign(self, mock_is_old, mock_factory):
-        client.factory = mock_factory
+    @mock.patch('aprsd.packets.WatchList.is_old')
+    def test_callsign_in_watchlist_old_same_alert_callsign(self, mock_is_old):
         mock_is_old.return_value = True
         self.config_and_init(
             watchlist_enabled=True,
-            watchlist_alert_callsign="WB4BOR",
-            watchlist_callsigns=["WB4BOR"],
+            watchlist_alert_callsign='WB4BOR',
+            watchlist_callsigns=['WB4BOR'],
         )
         plugin = notify_plugin.NotifySeenPlugin()
 
         packet = fake.fake_packet(
-            fromcall="WB4BOR",
-            message="ping",
+            fromcall='WB4BOR',
+            message='ping',
             msg_number=1,
         )
         actual = plugin.filter(packet)
         expected = packets.NULL_MESSAGE
         self.assertEqual(expected, actual)
 
-    @mock.patch("aprsd.client.ClientFactory", autospec=True)
-    @mock.patch("aprsd.packets.WatchList.is_old")
-    def test_callsign_in_watchlist_old_send_alert(self, mock_is_old, mock_factory):
-        client.factory = mock_factory
+    @mock.patch('aprsd.packets.WatchList.is_old')
+    def test_callsign_in_watchlist_old_send_alert(self, mock_is_old):
         mock_is_old.return_value = True
         notify_callsign = fake.FAKE_TO_CALLSIGN
-        fromcall = "WB4BOR"
+        fromcall = 'WB4BOR'
         self.config_and_init(
             watchlist_enabled=True,
             watchlist_alert_callsign=notify_callsign,
-            watchlist_callsigns=["WB4BOR"],
+            watchlist_callsigns=['WB4BOR'],
         )
         plugin = notify_plugin.NotifySeenPlugin()
 
         packet = fake.fake_packet(
             fromcall=fromcall,
-            message="ping",
+            message='ping',
             msg_number=1,
         )
         packet_type = packet.__class__.__name__
